#!/bin/bash
# This script deletes a DNS A record from the DNS server zone file (common::delete_dns_a_record)
# Bolt environment variables
NETWORK="${PT_network}"
ADD_A_RECORD="${PT_add_a_record_bool}"
HOSTNAME="${PT_dns_hostname}"

# Check if we should add DNS record based on network and add_a_record_bool
if [ "$ADD_A_RECORD" != "true" ] || [ "$NETWORK" != "wan-verizon" ]; then
    echo '{"status": "skipped", "message": "Skipping public facing DNS A record deletion based on configuration"}'
    exit 0
fi

# Check if required parameters are provided
if [ -z "$HOSTNAME" ]; then
    echo '{"status": "failure", "message": "Error: dns_hostname parameter must be provided"}'
    exit 1
fi

# Delete DNS A record
nsupdate -k "./keys/tsig.key" << EOF
server ns1.moeny.ai
debug yes
zone moeny.ai
update delete ${HOSTNAME}.moeny.ai A
send
EOF

# Force zone file update on DNS server
ssh moeny@ns1.moeny.ai "sudo rndc sync moeny.ai"

echo '{"status": "success", "message": "A Record successfully deleted."}'